@@ -6,12 +6,11 @@
 !BOP
 ! !ROUTINE: findband
 ! !INTERFACE:
-subroutine findband(sol,l,k,np,nr,r,vr,eps,demax,e,fnd)
+subroutine findband(sol,l,k,nr,r,vr,eps,demax,e,fnd)
 ! !INPUT/OUTPUT PARAMETERS:
 !   sol   : speed of light in atomic units (in,real)
 !   l     : angular momentum quantum number (in,integer)
 !   k     : quantum number k, zero if Dirac eqn. is not to be used (in,integer)
-!   np    : order of predictor-corrector polynomial (in,integer)
 !   nr    : number of radial mesh points (in,integer)
 !   r     : radial mesh (in,real(nr))
 !   vr    : potential on radial mesh (in,real(nr))
@@ -33,6 +32,7 @@ subroutine findband(sol,l,k,np,nr,r,vr,eps,demax,e,fnd)
 !
 ! !REVISION HISTORY:
 !   Created September 2004 (JKD)
+!   Added two-pass loop, October 2013 (JKD)
 !EOP
 !BOC
 implicit none
@@ -40,7 +40,6 @@ implicit none
 real(8), intent(in) :: sol
 integer, intent(in) :: l
 integer, intent(in) :: k
-integer, intent(in) :: np
 integer, intent(in) :: nr
 real(8), intent(in) :: r(nr)
 real(8), intent(in) :: vr(nr)
@@ -49,61 +48,81 @@ real(8), intent(in) :: demax
 real(8), intent(inout) :: e
 logical, intent(out) :: fnd
 ! local variables
+logical ft,fb
 ! maximum number of steps
-integer, parameter :: maxstp=1000
-integer ie,nn
+integer, parameter :: maxstp=250
+integer ip,ie,nn
 ! initial step size
 real(8), parameter :: de0=0.001d0
 real(8) de,et,eb,t,tp
 ! automatic arrays
 real(8) p0(nr),p1(nr),q0(nr),q1(nr)
-fnd=.false.
-tp=0.d0
-! find the top of the band
-de=de0
+ft=.false.
+fb=.false.
 et=e
-do ie=1,maxstp
-  et=et+de
-  if (e.lt.0.d0) then
-    if (et.gt.e+demax) return
-  end if
-  call rschroddme(sol,0,l,k,et,np,nr,r,vr,nn,p0,p1,q0,q1)
-  t=p0(nr)
-  if (ie.gt.1) then
-    if (t*tp.le.0.d0) then
-      if (abs(de).lt.eps) goto 10
-      de=-0.5d0*de
-    else
-      de=1.5d0*de
+eb=e
+! two-pass loop
+do ip=1,2
+! find the top of the band
+  tp=0.d0
+  de=de0
+  do ie=1,maxstp
+    et=et+de
+    if (e.lt.0.d0) then
+      if (et.gt.e+demax) exit
     end if
+    call rschroddme(sol,0,l,k,et,nr,r,vr,nn,p0,p1,q0,q1)
+    t=p0(nr)
+    if (ie.gt.1) then
+      if (t*tp.le.0.d0) then
+        if (abs(de).lt.eps) then
+          if (fb) goto 10
+          ft=.true.
+          eb=et+5.d0*abs(de0)
+          exit
+        end if
+        de=-0.5d0*de
+      else
+        de=1.5d0*de
+      end if
+    end if
+    tp=t
+  end do
+  if (fb) then
+    fnd=.false.
+    return
   end if
-  tp=t
+! find the bottom of the band
+  tp=0.d0
+  de=-de0
+  do ie=1,maxstp
+    eb=eb+de
+    if (eb.lt.e-demax) then
+      fnd=.false.
+      return
+    end if
+    call rschroddme(sol,0,l,k,eb,nr,r,vr,nn,p0,p1,q0,q1)
+    t=p1(nr)
+    if (ie.gt.1) then
+      if (t*tp.le.0.d0) then
+        if (abs(de).lt.eps) then
+          if (ft) goto 10
+          fb=.true.
+          et=eb-5.d0*abs(de0)
+          exit
+        end if
+        de=-0.5d0*de
+      else
+        de=1.5d0*de
+      end if
+    end if
+    tp=t
+  end do
 end do
+fnd=.false.
 return
 10 continue
-! find the bottom of the band
-de=-de0
-eb=et+5.d0*abs(de0)
-do ie=1,maxstp
-  eb=eb+de
-  if (e.lt.0.d0) then
-    if (eb.lt.e-demax) return
-  end if
-  call rschroddme(sol,0,l,k,eb,np,nr,r,vr,nn,p0,p1,q0,q1)
-  t=p1(nr)
-  if (ie.gt.1) then
-    if (t*tp.le.0.d0) then
-      if (abs(de).lt.eps) goto 20
-      de=-0.5d0*de
-    else
-      de=1.5d0*de
-    end if
-  end if
-  tp=t
-end do
-return
-20 continue
-! set the band energy to the mid-point
+! set the band energy halfway between top and bottom
 e=(et+eb)/2.d0
 fnd=.true.
 return
