@@ -9,6 +9,7 @@
 subroutine genrmesh
 ! !USES:
 use modmain
+use modvars
 ! !DESCRIPTION:
 !   Generates the coarse and fine radial meshes for each atomic species in the
 !   crystal. Also determines which points are in the inner part of the
@@ -56,8 +57,8 @@ do is=1,nspecies
     irc=irc+1
     rcmt(irc,is)=spr(ir,is)
     if (spr(ir,is).lt.t1) then
-      nrmtinr(is)=ir-1
-      nrcmtinr(is)=irc-1
+      nrmtinr(is)=ir
+      nrcmtinr(is)=irc
     end if
   end do
 end do
@@ -67,6 +68,16 @@ do is=1,nspecies
     if (spr(ir,is).lt.radfhf) irfhf(is)=ir
   end do
 end do
+! write to VARIABLES.OUT
+call writevars('spnr',nv=nspecies,iva=spnr)
+call writevars('nrmt',nv=nspecies,iva=nrmt)
+call writevars('nrmtinr',nv=nspecies,iva=nrmtinr)
+call writevars('lradstp',iv=lradstp)
+call writevars('nrcmt',nv=nspecies,iva=nrcmt)
+call writevars('nrcmtinr',nv=nspecies,iva=nrcmtinr)
+do is=1,nspecies
+  call writevars('spr',nv=nrmt(is),rva=spr(:,is))
+end do
 return
 end subroutine
 !EOC
