@@ -85,13 +85,6 @@ if (trdstate) then
   call readstate
   if (mp_mpi) then
     write(60,'("Potential read in from STATE.OUT")')
-    if (fixspin.ne.0) then
-      write(*,*)
-      write(*,'("Warning(gndstate): fixed spin moment calculation resumed &
-       &from STATE.OUT")')
-      write(*,'("This may get trapped in a metastable state")')
-      write(*,'("Better to start from atomic density (task = 0)")')
-    end if
   end if
   if (autolinengy) call readfermi
 else
@@ -109,7 +102,7 @@ if (ldapu.ne.0) n=n+2*lmmaxlu*lmmaxlu*nspinor*nspinor*natmtot
 allocate(v(n))
 ! determine the size of the mixer work array
 nwork=-1
-call mixerifc(mixtype,n,v,dv,nwork,work)
+call mixerifc(mixtype,n,v,dv,nwork,v)
 allocate(work(nwork))
 ! set last self-consistent loop flag
 tlast=.false.
