@@ -178,6 +178,8 @@ integer, allocatable :: idxil(:),idxim(:)
 logical spinpol
 ! spinorb is .true. for spin-orbit coupling
 logical spinorb
+! scale factor of spin-orbit coupling term in Hamiltonian
+real(8) socscf
 ! fixed spin moment type
 !  0      : none
 !  1 (-1) : total moment (direction)
@@ -441,10 +443,18 @@ real(8), allocatable :: wiq2(:)
 real(8), allocatable :: rbshtvr(:,:)
 ! real forward SHT matrix for lmaxvr
 real(8), allocatable :: rfshtvr(:,:)
+! real backward SHT matrix for lmaxinr
+real(8), allocatable :: rbshtinr(:,:)
+! real forward SHT matrix for lmaxinr
+real(8), allocatable :: rfshtinr(:,:)
 ! complex backward SHT matrix for lmaxvr
 complex(8), allocatable :: zbshtvr(:,:)
 ! complex forward SHT matrix for lmaxvr
 complex(8), allocatable :: zfshtvr(:,:)
+! complex backward SHT matrix for lmaxinr
+complex(8), allocatable :: zbshtinr(:,:)
+! complex forward SHT matrix for lmaxinr
+complex(8), allocatable :: zfshtinr(:,:)
 
 !-----------------------------------------!
 !     potential and density variables     !
@@ -771,8 +781,6 @@ real(8) engyvxc
 real(8) engybxc
 ! energy of external global magnetic field
 real(8) engybext
-! energy of muffin-tin magnetic fields (non-physical)
-real(8) engybmt
 ! exchange energy
 real(8) engyx
 ! correlation energy
@@ -1066,7 +1074,7 @@ real(8), parameter :: amu=1822.88848426d0
 !---------------------------------!
 ! code version
 integer version(3)
-data version / 2,2,5 /
+data version / 2,2,10 /
 ! maximum number of tasks
 integer, parameter :: maxtasks=40
 ! number of tasks
@@ -1079,6 +1087,8 @@ integer task
 logical tlast
 ! number of self-consistent loops after which STATE.OUT is written
 integer nwrite
+! if wrtvars is .true. then variables are written to VARIABLES.OUT
+logical wrtvars
 ! filename extension for files generated by gndstate
 character(256) filext
 ! default file extension
