@@ -30,6 +30,8 @@ real(8) mommtfix0(3,maxatoms,maxspecies)
 logical tforce0
 logical autokpt0
 integer ngridk0(3)
+real(8) vkloff0(3)
+logical ptnucl0
 
 end module
 
