@@ -12,7 +12,7 @@ complex(8), intent(out) :: vnlcv(ncrmax,natmtot,nstsv)
 complex(8), intent(out) :: vnlvv(nstsv,nstsv)
 ! local variables
 integer ik,jk,ist1,ist2,ist3
-integer is,ia,ias,nrc,nrci,n
+integer is,ia,ias,nrc,nrci
 integer iv(3),ig,iq,igq0
 integer ic,jc,m1,m2
 real(8) v(3),cfq
@@ -106,7 +106,6 @@ do ik=1,nkptnr
       do is=1,nspecies
         nrc=nrcmt(is)
         nrci=nrcmtinr(is)
-        n=lmmaxvr*nrc
         do ia=1,natoms(is)
           ias=idxas(ia,is)
           do ist1=1,spnst(is)
@@ -116,10 +115,11 @@ do ik=1,nkptnr
 ! pass m-1/2 to wavefcr
                 call wavefcr(.false.,lradstp,is,ia,ist1,m1,nrcmtmax,wfcr1)
                 if (spinpol) then
-                  call zvmul2(n,wfmt2(:,:,ias,1,ist3),wfcr1(:,:,1), &
-                   wfmt2(:,:,ias,2,ist3),wfcr1(:,:,2),zfmt)
+                  call zfmtmul2(nrc,nrci,wfmt2(:,:,ias,1,ist3), &
+                   wfmt2(:,:,ias,2,ist3),wfcr1(:,:,1),wfcr1(:,:,2),zfmt)
                 else
-                  call zvmul1(n,wfmt2(:,:,ias,1,ist3),wfcr1(:,:,1),zfmt)
+                  call zfmtmul1(nrc,nrci,wfmt2(:,:,ias,1,ist3),wfcr1(:,:,1), &
+                   zfmt)
                 end if
 ! convert to spherical harmonics
                 call zfsht(nrc,nrci,zfmt,zrhomt2(:,:,jc))
@@ -131,10 +131,10 @@ do ik=1,nkptnr
       do ist2=1,nstsv
         if (evalsv(ist2,ikp).gt.efermi) then
 ! calculate the Coulomb potential
-          call genzvclmt(nrcmt,nrcmtmax,rcmt,nrcmtmax,zrhomt1(:,:,:,ist2), &
-           zvclmt)
-          call zpotcoul(nrcmt,nrcmtmax,rcmt,igq0,gqc,jlgqr,ylmgq,sfacgq, &
-           zrhoir1(:,ist2),nrcmtmax,zvclmt,zvclir,zrho02)
+          call genzvclmt(nrcmt,nrcmtinr,nrcmtmax,rcmt,nrcmtmax, &
+           zrhomt1(:,:,:,ist2),zvclmt)
+          call zpotcoul(nrcmt,nrcmtinr,nrcmtmax,rcmt,igq0,gqc,jlgqr,ylmgq, &
+           sfacgq,zrhoir1(:,ist2),nrcmtmax,zvclmt,zvclir,zrho02)
 !----------------------------------------------!
 !     valence-valence-valence contribution     !
 !----------------------------------------------!
@@ -185,7 +185,6 @@ end do
 do is=1,nspecies
   nrc=nrcmt(is)
   nrci=nrcmtinr(is)
-  n=lmmaxvr*nrc
   do ia=1,natoms(is)
     ias=idxas(ia,is)
     do ist3=1,spnst(is)
@@ -196,10 +195,10 @@ do is=1,nspecies
 ! compute the complex overlap densities for the core-valence states
           do ist1=1,nstsv
             if (spinpol) then
-              call zvmul2(n,wfcr1(:,:,1),wfmt1(:,:,ias,1,ist1),wfcr1(:,:,2), &
-               wfmt1(:,:,ias,2,ist1),zfmt)
+              call zfmtmul2(nrc,nrci,wfcr1(:,:,1),wfcr1(:,:,2), &
+               wfmt1(:,:,ias,1,ist1),wfmt1(:,:,ias,2,ist1),zfmt)
             else
-              call zvmul1(n,wfcr1(:,:,1),wfmt1(:,:,ias,1,ist1),zfmt)
+              call zfmtmul1(nrc,nrci,wfcr1(:,:,1),wfmt1(:,:,ias,1,ist1),zfmt)
             end if
             call zfsht(nrc,nrci,zfmt,zrhomt1(:,:,ias,ist1))
           end do
@@ -210,7 +209,7 @@ do is=1,nspecies
               do m2=-spk(ist1,is),spk(ist1,is)-1
                 ic=ic+1
                 call wavefcr(.false.,lradstp,is,ia,ist1,m2,nrcmtmax,wfcr2)
-                call zvmul2(n,wfcr1(:,:,1),wfcr2(:,:,1),wfcr1(:,:,2), &
+                call zfmtmul2(nrc,nrci,wfcr1(:,:,1),wfcr1(:,:,2),wfcr2(:,:,1), &
                  wfcr2(:,:,2),zfmt)
                 call zfsht(nrc,nrci,zfmt,zrhomt2(:,:,ic))
               end do
@@ -219,8 +218,7 @@ do is=1,nspecies
           do ist2=1,nstsv
             if (evalsv(ist2,ikp).gt.efermi) then
 ! calculate the Coulomb potential
-              call zpotclmt(lmaxvr,nrc,rcmt(:,is),lmmaxvr, &
-               zrhomt1(:,:,ias,ist2),zvclmt)
+              call zpotclmt(nrc,nrci,rcmt(:,is),zrhomt1(:,:,ias,ist2),zvclmt)
 !-------------------------------------------!
 !     valence-core-valence contribution     !
 !-------------------------------------------!
@@ -262,27 +260,6 @@ deallocate(wfmt1,wfmt2,wfir1,wfir2,wfcr1,wfcr2)
 deallocate(zrhomt1,zrhomt2,zrhoir1)
 deallocate(zvclmt,zvclir,zfmt)
 return
-
-contains
-
-subroutine zvmul1(n,x,y,z)
-implicit none
-integer, intent(in) :: n
-complex(8), intent(in) :: x(n),y(n)
-complex(8), intent(out) :: z(n)
-z(:)=conjg(x(:))*y(:)
-return
-end subroutine
-
-subroutine zvmul2(n,x1,y1,x2,y2,z)
-implicit none
-integer, intent(in) :: n
-complex(8), intent(in) :: x1(n),y1(n),x2(n),y2(n)
-complex(8), intent(out) :: z(n)
-z(:)=conjg(x1(:))*y1(:)+conjg(x2(:))*y2(:)
-return
-end subroutine
-
 end subroutine
 !EOC
 
