@@ -6,16 +6,14 @@
 !BOP
 ! !ROUTINE: plot1d
 ! !INTERFACE:
-subroutine plot1d(fnum1,fnum2,nf,lmax,ld,rfmt,rfir)
+subroutine plot1d(fnum1,fnum2,nf,rfmt,rfir)
 ! !USES:
 use modmain
 ! !INPUT/OUTPUT PARAMETERS:
 !   fnum1 : plot file number (in,integer)
 !   fnum2 : vertex location file number (in,integer)
 !   nf    : number of functions (in,integer)
-!   lmax  : maximum angular momentum (in,integer)
-!   ld    : leading dimension (in,integer)
-!   rfmt  : real muffin-tin function (in,real(ld,nrmtmax,natmtot,nf))
+!   rfmt  : real muffin-tin function (in,real(lmmaxvr,nrmtmax,natmtot,nf))
 !   rfir  : real intersitial function (in,real(ngtot,nf))
 ! !DESCRIPTION:
 !   Produces a 1D plot of the real functions contained in arrays {\tt rfmt} and
@@ -28,12 +26,9 @@ use modmain
 !BOC
 implicit none
 ! arguments
-integer, intent(in) :: fnum1
-integer, intent(in) :: fnum2
+integer, intent(in) :: fnum1,fnum2
 integer, intent(in) :: nf
-integer, intent(in) :: lmax
-integer, intent(in) :: ld
-real(8), intent(in) :: rfmt(ld,nrmtmax,natmtot,nf)
+real(8), intent(in) :: rfmt(lmmaxvr,nrmtmax,natmtot,nf)
 real(8), intent(in) :: rfir(ngtot,nf)
 ! local variables
 integer i,ip,iv
@@ -51,7 +46,7 @@ allocate(fp(npp1d,nf))
 call connect(avec,nvp1d,npp1d,vvlp1d,vplp1d,dvp1d,dpp1d)
 do i=1,nf
 ! evaluate function at each point
-  call rfarray(lmax,ld,rfmt(:,:,:,i),rfir(:,i),npp1d,vplp1d,fp(:,i))
+  call rfarray(npp1d,vplp1d,rfmt(:,:,:,i),rfir(:,i),fp(:,i))
 end do
 fmin=fp(1,1)
 fmax=fp(1,1)
