@@ -17,6 +17,7 @@ use modtest
 use modrandom
 use modscdft
 use modpw
+use modvars
 ! !DESCRIPTION:
 !   Reads in the input parameters from the file {\tt elk.in}. Also sets default
 !   values for the input parameters.
@@ -122,6 +123,7 @@ dosssum=.false.
 lmirep=.true.
 spinpol=.false.
 spinorb=.false.
+socscf=1.d0
 maxatpstp=200
 tau0atp=0.25d0
 deltast=0.01d0
@@ -136,7 +138,7 @@ optcomp(:,1)=1
 intraband=.false.
 evaltol=-1.d0
 epsband=1.d-12
-demaxbnd=2.d0
+demaxbnd=2.5d0
 autolinengy=.false.
 dlefe=-0.1d0
 bfieldc0(:)=0.d0
@@ -247,7 +249,8 @@ nrmtscf=1
 lmaxdos=3
 epsph=0.01d0
 msmooth=0
-npmae=6
+npmae=4
+wrtvars=.false.
 
 !--------------------------!
 !     read from elk.in     !
@@ -407,6 +410,14 @@ case('spinpol')
   read(50,*,err=20) spinpol
 case('spinorb')
   read(50,*,err=20) spinorb
+case('socscf')
+  read(50,*,err=20) socscf
+  if (socscf.lt.0.d0) then
+    write(*,*)
+    write(*,'("Error(readinput): socscf < 0 : ",G18.10)') socscf
+    write(*,*)
+    stop
+  end if
 case('xctype')
   read(50,'(A256)',err=20) str
   str=trim(str)//' 0 0'
@@ -1235,7 +1246,6 @@ case('highq')
     lmaxapw=10
     lmaxvr=8
     lmaxmat=7
-    autoswidth=.true.
     radkpt=60.d0
     autokpt=.true.
     vkloff(:)=0.d0
@@ -1315,10 +1325,12 @@ case('npmae')
   read(50,*,err=20) npmae
   if (npmae.le.1) then
     write(*,*)
-    write(*,'("Error(readinput): npmae <= 0 : ",I8)') npmae
+    write(*,'("Error(readinput): npmae <= 1 : ",I8)') npmae
     write(*,*)
     stop
   end if
+case('wrtvars')
+  read(50,*,err=20) wrtvars
 case('')
   goto 10
 case default
