@@ -10,8 +10,7 @@ implicit none
 integer ik,ist
 real(8) x,t1
 ! allocatable arrays
-complex(8), allocatable :: evecfv(:,:)
-complex(8), allocatable :: evecsv(:,:)
+complex(8), allocatable :: evecfv(:,:),evecsv(:,:)
 ! external functions
 real(8) sdelta
 external sdelta
@@ -85,7 +84,7 @@ select case(task)
 case(61)
   open(50,file='WF1D.OUT',action='WRITE',form='FORMATTED')
   open(51,file='WFLINES.OUT',action='WRITE',form='FORMATTED')
-  call plot1d(50,51,1,lmaxvr,lmmaxvr,rhomt,rhoir)
+  call plot1d(50,51,1,rhomt,rhoir)
   close(50)
   close(51)
   write(*,*)
@@ -94,21 +93,21 @@ case(61)
   write(*,'(" vertex location lines written to WFLINES.OUT")')
 case(62)
   open(50,file='WF2D.OUT',action='WRITE',form='FORMATTED')
-  call plot2d(50,1,lmaxvr,lmmaxvr,rhomt,rhoir)
+  call plot2d(50,1,rhomt,rhoir)
   close(50)
   write(*,*)
   write(*,'("Info(wfplot):")')
   write(*,'(" 2D wavefunction modulus squared written to WF2D.OUT")')
 case(162)
   open(50,file='STM2D.OUT',action='WRITE',form='FORMATTED')
-  call plot2d(50,1,lmaxvr,lmmaxvr,rhomt,rhoir)
+  call plot2d(50,1,rhomt,rhoir)
   close(50)
   write(*,*)
   write(*,'("Info(wfplot):")')
   write(*,'(" 2D STM image written to STM2D.OUT")')
 case(63)
   open(50,file='WF3D.OUT',action='WRITE',form='FORMATTED')
-  call plot3d(50,1,lmaxvr,lmmaxvr,rhomt,rhoir)
+  call plot3d(50,1,rhomt,rhoir)
   close(50)
   write(*,*)
   write(*,'("Info(wfplot):")')
